Bug 1351474 - use Mozilla fork of libdmg-hfsplus; r?ted draft
authorMike Shal <mshal@mozilla.com>
Thu, 30 Mar 2017 16:30:59 -0400
changeset 553872 251413bcca312c30982beadcae5fa7bb961b9008
parent 553679 03d602fd723ad6ff4588c04855884ffa1dee9410
child 553873 fda21c7640313697bad33b5d3e7602953adac542
push id51813
push userbmo:mshal@mozilla.com
push dateThu, 30 Mar 2017 22:26:42 +0000
reviewersted
bugs1351474
milestone55.0a1
Bug 1351474 - use Mozilla fork of libdmg-hfsplus; r?ted The latest upstream version produces .dmg files that have fsck errors, and some versions of OSX complain that the image is corrupted. The previous version of libdmg-hfsplus that we were using (1d72dd62a) doesn't have fsck errors, but it also doesn't preserve file permissions. Our fork is based on the older version and backports the file permission commits. MozReview-Commit-ID: Bjwy6MJ98Ud
taskcluster/scripts/misc/build-libdmg-hfsplus.sh
--- a/taskcluster/scripts/misc/build-libdmg-hfsplus.sh
+++ b/taskcluster/scripts/misc/build-libdmg-hfsplus.sh
@@ -3,21 +3,22 @@ set -x -e -v
 
 # This script is for building libdmg-hfsplus to get the `dmg` and `hfsplus`
 # tools for producing DMG archives on Linux.
 
 WORKSPACE=$HOME/workspace
 STAGE=$WORKSPACE/dmg
 UPLOAD_DIR=$WORKSPACE/artifacts
 
-# There's no single well-maintained fork of libdmg-hfsplus, but this
-# branch currently has some fixes we need.
-: LIBDMG_REPOSITORY    ${LIBDMG_REPOSITORY:=https://github.com/andreas56/libdmg-hfsplus}
-# This is the current head of the `from_zarvox` branch.
-: LIBDMG_REV           ${LIBDMG_REV:=81dd75fd1549b24bf8af9736ac25518b367e6b63}
+# There's no single well-maintained fork of libdmg-hfsplus, so we forked
+# https://github.com/andreas56/libdmg-hfsplus/ to get a specific version and
+# backport some patches.
+: LIBDMG_REPOSITORY    ${LIBDMG_REPOSITORY:=https://github.com/mozilla/libdmg-hfsplus}
+# The `mozilla` branch contains our fork.
+: LIBDMG_REV           ${LIBDMG_REV:=mozilla}
 
 mkdir -p $UPLOAD_DIR $STAGE
 
 cd $WORKSPACE
 tc-vcs checkout --force-clone libdmg-hfsplus $LIBDMG_REPOSITORY $LIBDMG_REPOSITORY $LIBDMG_REV
 cd libdmg-hfsplus
 # Make a source archive
 git archive ${LIBDMG_REV} | xz > $UPLOAD_DIR/libdmg-hfsplus.tar.xz